@@ -1,9 +1,8 @@
 from dataclasses import dataclass
-from typing import Optional, List, Dict, Tuple, AnyStr, Any
+from typing import Dict, List, Optional, Tuple
 
 import aiohttp
-
-from .base_functions import *
+from yarl import URL
 
 
 @dataclass
@@ -40,6 +39,14 @@ class DomainItem:
         else:
             self.albums[title] = album
 
+    async def append_title(self, title):
+        new_albums = {}
+        for album_str, album in self.albums.items():
+            new_title = title+'/'+album_str
+            new_albums[new_title] = album
+            album.title = new_title
+        self.albums = new_albums
+
 
 @dataclass
 class CascadeItem:
